{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-24.11";
    nixpkgsUnstable.url = "github:NixOS/nixpkgs/nixos-unstable";
    utils.url = "github:numtide/flake-utils";
    naersk.url = "github:nix-community/naersk/master";
  };

  outputs =
    {
      self,
      nixpkgs,
      nixpkgsUnstable,
      utils,
      naersk,
    }:
    utils.lib.eachDefaultSystem (
      system:
      let
        pkgs = import nixpkgs { inherit system; };
        pkgsUnstable = import nixpkgsUnstable { inherit system; };
        naersk' = pkgs.callPackage naersk { };
      in
      {
        devShell =
          with pkgs;
          mkShell.override { stdenv = pkgs.clangStdenv; } {
            nativeBuildInputs = [
              cargo
              rustc
              rustfmt
              rustPackages.clippy
              cargo-watch
              pkgsUnstable.dioxus-cli
              pkgsUnstable.wasm-bindgen-cli
              llvmPackages.bintools
              pkg-config
              pkgsUnstable.overturemaps
              pkgsUnstable.duckdb
              pre-commit
              overmind
              redis
              minio
            ];
            buildInputs = [
              webkitgtk_4_1
              gtk3
              xdotool.out
              openssl
            ];
            shellHook = ''
              # pre-commit install
            '';
            RUST_SRC_PATH = rustPlatform.rustLibSrc;
          };
      }
    );
}
